@@ -40,8 +40,11 @@ str_alphord_nums <- function(string) {
     bad_index <- match(F, have_nums)
     rlang::abort(
       c("Some of the input strings have no numbers in them.",
-        x = str_glue("The first bad string is string number {bad_index}, ",
-                     "which is '{string[bad_index]}'."))
+        x = str_glue(
+          "The first bad string is string number {bad_index}, ",
+          "which is '{string[bad_index]}'."
+        )
+      )
     )
   }
   non_nums <- str_extract_non_numerics(string)
@@ -52,9 +55,12 @@ str_alphord_nums <- function(string) {
     }
     rlang::abort(
       c("The non-number bits of every string must be the same.",
-        i = str_glue("The first pair of strings with different non-",
-                     "number bits are strings 1 and {bad_index}."),
-        x = str_glue("They are '{string[1]}' and '{string[bad_index]}'."))
+        i = str_glue(
+          "The first pair of strings with different non-",
+          "number bits are strings 1 and {bad_index}."
+        ),
+        x = str_glue("They are '{string[1]}' and '{string[bad_index]}'.")
+      )
     )
   }
   nums <- str_extract_numbers(string, leave_as_string = TRUE)
@@ -63,17 +69,21 @@ str_alphord_nums <- function(string) {
     bad_index <- match(F, nums_lengths == nums_lengths[1])
     rlang::abort(
       c("The strings must all have the same number of numbers.",
-        x = str_glue("Your string number 1 \"{string[1]}\" has ",
-                     "{nums_lengths[1]} numbers, whereas your string number ",
-                     "{bad_index} '{string[bad_index]}' has ",
-                     "{nums_lengths[bad_index]} numbers."))
+        x = str_glue(
+          "Your string number 1 \"{string[1]}\" has ",
+          "{nums_lengths[1]} numbers, whereas your string number ",
+          "{bad_index} '{string[bad_index]}' has ",
+          "{nums_lengths[bad_index]} numbers."
+        )
+      )
     )
   }
   nums <- simplify2array(nums)
   if (!is.matrix(nums)) nums <- t(nums)
-  ncn <- nums %>% {
-    array(str_length(.), dim = dim(.))
-  }
+  ncn <- nums %>%
+    {
+      array(str_length(.), dim = dim(.))
+    }
   max_lengths <- int_mat_row_maxs(ncn)
   min_length <- min(ncn)
   to_prefix <- rep("0", max(max_lengths) - min_length) %>% str_c(collapse = "")
@@ -85,14 +95,20 @@ str_alphord_nums <- function(string) {
   if (length(unique(num_first)) > 1) {
     bad_index <- match(!num_first[1], num_first)
     rlang::abort(
-      c(paste("It should either be the case that all strings start with",
-              "numbers or that none of them do."),
-        x = str_glue(" String number 1 '{string[1]}' ",
-                     "{ifelse(num_first[1], 'does', 'does not')} ",
-                     "start with a number whereas ",
-                     "string number {bad_index} '{string[bad_index]}' ",
-                     "{ifelse(num_first[1], 'does not', 'does')} ",
-                     "start with a number."))
+      c(
+        paste(
+          "It should either be the case that all strings start with",
+          "numbers or that none of them do."
+        ),
+        x = str_glue(
+          " String number 1 '{string[1]}' ",
+          "{ifelse(num_first[1], 'does', 'does not')} ",
+          "start with a number whereas ",
+          "string number {bad_index} '{string[bad_index]}' ",
+          "{ifelse(num_first[1], 'does not', 'does')} ",
+          "start with a number."
+        )
+      )
     )
   }
   if (num_first[1]) {
