@@ -24,8 +24,14 @@
 str_nth_number_after_mth <- function(string, pattern, n, m,
                                      decimals = FALSE,
                                      leading_decimals = decimals,
-                                     negs = FALSE, sci = FALSE, commas = FALSE,
-                                     leave_as_string = FALSE) {
+                                     negs = FALSE, sci = FALSE, big_mark = "",
+                                     leave_as_string = FALSE, commas = FALSE) {
+  if (!isFALSE(commas)) {
+    lifecycle::deprecate_stop(
+      "2.0.0", "strex::str_nth_number_after_mth(commas)",
+      details = "Use the `big_mark` argument instead."
+    )
+  }
   checkmate::assert_flag(leave_as_string)
   if (is_l0_char(string)) {
     return(vector(mode = ifelse(leave_as_string, "character", "numeric")))
@@ -35,13 +41,13 @@ str_nth_number_after_mth <- function(string, pattern, n, m,
   checkmate::assert_flag(leading_decimals)
   checkmate::assert_flag(negs)
   checkmate::assert_flag(sci)
-  checkmate::assert_flag(commas)
+  checkmate::assert_string(big_mark)
   string %>%
     str_after_nth(pattern, m) %>%
     str_nth_number(n,
       decimals = decimals, leading_decimals = leading_decimals,
       negs = negs, leave_as_string = leave_as_string, sci = sci,
-      commas = commas
+      big_mark = big_mark
     )
 }
 
@@ -52,13 +58,14 @@ str_nth_number_after_mth <- function(string, pattern, n, m,
 str_nth_number_after_first <- function(string, pattern, n, decimals = FALSE,
                                        leading_decimals = decimals,
                                        negs = FALSE, sci = FALSE,
-                                       commas = FALSE,
-                                       leave_as_string = FALSE) {
+                                       big_mark = "",
+                                       leave_as_string = FALSE,
+                                       commas = FALSE) {
   str_nth_number_after_mth(string, pattern,
     n = n, m = 1,
     decimals = decimals,
-    leading_decimals = leading_decimals, sci = sci, commas = commas,
-    negs = negs, leave_as_string = leave_as_string
+    leading_decimals = leading_decimals, sci = sci, big_mark = big_mark,
+    negs = negs, leave_as_string = leave_as_string, commas = commas
   )
 }
 
@@ -70,13 +77,15 @@ str_nth_number_after_last <- function(string, pattern, n,
                                       decimals = FALSE,
                                       leading_decimals = decimals,
                                       negs = FALSE, sci = FALSE,
-                                      commas = FALSE,
-                                      leave_as_string = FALSE) {
+                                      big_mark = "",
+                                      leave_as_string = FALSE,
+                                      commas = FALSE) {
   str_nth_number_after_mth(string, pattern,
     n = n, m = -1,
     decimals = decimals,
     leading_decimals = leading_decimals,
-    negs = negs, leave_as_string = leave_as_string
+    negs = negs, leave_as_string = leave_as_string,
+    commas = commas
   )
 }
 
@@ -88,13 +97,15 @@ str_first_number_after_mth <- function(string, pattern, m,
                                        decimals = FALSE,
                                        leading_decimals = decimals,
                                        negs = FALSE, sci = FALSE,
-                                       commas = FALSE,
-                                       leave_as_string = FALSE) {
+                                       big_mark = "",
+                                       leave_as_string = FALSE,
+                                       commas = FALSE) {
   str_nth_number_after_mth(string, pattern,
     n = 1, m = m,
     decimals = decimals,
-    leading_decimals = leading_decimals, sci = sci, commas = commas,
-    negs = negs, leave_as_string = leave_as_string
+    leading_decimals = leading_decimals, sci = sci, big_mark = big_mark,
+    negs = negs, leave_as_string = leave_as_string,
+    commas = commas
   )
 }
 
@@ -106,13 +117,15 @@ str_last_number_after_mth <- function(string, pattern, m,
                                       decimals = FALSE,
                                       leading_decimals = decimals,
                                       negs = FALSE, sci = FALSE,
-                                      commas = FALSE,
-                                      leave_as_string = FALSE) {
+                                      big_mark = "",
+                                      leave_as_string = FALSE,
+                                      commas = FALSE) {
   str_nth_number_after_mth(string, pattern,
     n = -1, m = m,
     decimals = decimals,
-    leading_decimals = leading_decimals, sci = sci, commas = commas,
-    negs = negs, leave_as_string = leave_as_string
+    leading_decimals = leading_decimals, sci = sci, big_mark = big_mark,
+    negs = negs, leave_as_string = leave_as_string,
+    commas = commas
   )
 }
 
@@ -124,13 +137,15 @@ str_first_number_after_first <- function(string, pattern,
                                          decimals = FALSE,
                                          leading_decimals = decimals,
                                          negs = FALSE, sci = FALSE,
-                                         commas = FALSE,
-                                         leave_as_string = FALSE) {
+                                         big_mark = "",
+                                         leave_as_string = FALSE,
+                                         commas = FALSE) {
   str_nth_number_after_mth(string, pattern,
     n = 1, m = 1,
     decimals = decimals,
-    leading_decimals = leading_decimals, sci = sci, commas = commas,
-    negs = negs, leave_as_string = leave_as_string
+    leading_decimals = leading_decimals, sci = sci, big_mark = big_mark,
+    negs = negs, leave_as_string = leave_as_string,
+    commas = commas
   )
 }
 
@@ -142,13 +157,15 @@ str_first_number_after_last <- function(string, pattern,
                                         decimals = FALSE,
                                         leading_decimals = decimals,
                                         negs = FALSE,
-                                        sci = FALSE, commas = FALSE,
-                                        leave_as_string = FALSE) {
+                                        sci = FALSE, big_mark = "",
+                                        leave_as_string = FALSE,
+                                        commas = FALSE) {
   str_nth_number_after_mth(string, pattern,
     n = 1, m = -1,
-    decimals = decimals, sci = sci, commas = commas,
+    decimals = decimals, sci = sci, big_mark = big_mark,
     leading_decimals = leading_decimals,
-    negs = negs, leave_as_string = leave_as_string
+    negs = negs, leave_as_string = leave_as_string,
+    commas = commas
   )
 }
 
@@ -159,13 +176,15 @@ str_first_number_after_last <- function(string, pattern,
 str_last_number_after_first <- function(string, pattern, decimals = FALSE,
                                         leading_decimals = decimals,
                                         negs = FALSE,
-                                        sci = FALSE, commas = FALSE,
-                                        leave_as_string = FALSE) {
+                                        sci = FALSE, big_mark = "",
+                                        leave_as_string = FALSE,
+                                        commas = FALSE) {
   str_nth_number_after_mth(string, pattern,
     n = -1, m = 1,
-    decimals = decimals, sci = sci, commas = commas,
+    decimals = decimals, sci = sci, big_mark = big_mark,
     leading_decimals = leading_decimals,
-    negs = negs, leave_as_string = leave_as_string
+    negs = negs, leave_as_string = leave_as_string,
+    commas = commas
   )
 }
 
@@ -177,11 +196,13 @@ str_last_number_after_last <- function(string, pattern,
                                        decimals = FALSE,
                                        leading_decimals = decimals,
                                        negs = FALSE,
-                                       sci = FALSE, commas = FALSE,
-                                       leave_as_string = FALSE) {
+                                       sci = FALSE, big_mark = "",
+                                       leave_as_string = FALSE,
+                                       commas = FALSE) {
   str_nth_number_after_mth(string, pattern,
     n = -1, m = -1, decimals = decimals,
-    leading_decimals = leading_decimals, sci = sci, commas = commas,
-    negs = negs, leave_as_string = leave_as_string
+    leading_decimals = leading_decimals, sci = sci, big_mark = big_mark,
+    negs = negs, leave_as_string = leave_as_string,
+    commas = commas
   )
 }
